require_relative 'entities/context'
require_relative 'entities/directed_graph'

require_relative 'entities/identifier'
require_relative 'entities/content'
require_relative 'entities/processing_action'
require_relative 'entities/processing_actions'

require_relative 'entities/code_snippet'
require_relative 'entities/configuration'
require_relative 'entities/lazy_value'
require_relative 'entities/document'
require_relative 'entities/identifiable_collection'
require_relative 'entities/item'
require_relative 'entities/item_rep'
require_relative 'entities/layout'
require_relative 'entities/pattern'
require_relative 'entities/props'
require_relative 'entities/rule_memory'
require_relative 'entities/site'
require_relative 'entities/snapshot_def'

require_relative 'entities/outdatedness_status'
require_relative 'entities/outdatedness_reasons'
require_relative 'entities/dependency'
